ExternalAgreementType1Code

Enum ExternalAgreementType1Code 

pub enum ExternalAgreementType1Code {
Show 35 variants Ausl, Biag, Cara, Cdea, Chma, Chra, Cmop, Cnbr, Csda, Dema, Derd, Derp, Derv, Efma, Esra, Euma, Fmat, Fpca, Frfb, Gesl, Gmra, Gmsl, Idma, Isda, Jpbl, Jpbr, Jpsl, Krra, Krsl, Mefi, Mraa, Msla, Osla, Othr, Unknown,
}

Variants



Ausl



Biag



Cara



Cdea



Chma



Chra



Cmop



Cnbr



Csda



Dema



Derd



Derp



Derv



Efma



Esra



Euma



Fmat



Fpca



Frfb



Gesl



Gmra



Gmsl



Idma



Isda



Jpbl



Jpbr



Jpsl



Krra



Krsl



Mefi



Mraa



Msla



Osla



Othr



Unknown