ExternalCashClearingSystem1Code

Enum ExternalCashClearingSystem1Code 

pub enum ExternalCashClearingSystem1Code {
Show 122 variants Abe, Ach, Acs, Aip, Art, Avp, Azm, Bap, Bcc, Bce, Bds, Bel, Bgn, Bhs, Bis, Bof, Boj, Brl, Bsp, Cad, Cam, Cba, Cbc, Cbj, Cce, Chi, Chp, Cip, Cis, Coe, Coi, Cou, Ddk, Dkc, Eba, Els, Emz, Epm, Epn, Erp, Fda, Fdn, Fdw, Fey, Fps, Gis, Hkl, Hks, Hrk, Hrm, Huf, Ibp, Inc, Imp, Jod, Kps, Lgs, Lkb, Lvl, Lvt, Lyx, Mep, Mos, Mqq, Mrs, Mup, Nam, Noc, Nor, Npp, Nss, Nze, Pch, Pds, Peg, Pns, Psa, Ptr, Pve, Rol, Ros, Rtg, Rtp, Rtr, Scl, Scp, Sec, Seu, Sic, Sip, Sit, Slb, Spg, Ssk, St2, Stg, Tbf, Tch, Tgt, Thb, Thn, Tis, Top, Ttd, Ube, Uis, Upi, Vcs, Xct, Zen, Zet, Zis, Isg, Nbo, Isw, I27, B27, Ukd, Scr, Rix, Moc, Unknown,
}

Variants



Abe



Ach



Acs



Aip



Art



Avp



Azm



Bap



Bcc



Bce



Bds



Bel



Bgn



Bhs



Bis



Bof



Boj



Brl



Bsp



Cad



Cam



Cba



Cbc



Cbj



Cce



Chi



Chp



Cip



Cis



Coe



Coi



Cou



Ddk



Dkc



Eba



Els



Emz



Epm



Epn



Erp



Fda



Fdn



Fdw



Fey



Fps



Gis



Hkl



Hks



Hrk



Hrm



Huf



Ibp



Inc



Imp



Jod



Kps



Lgs



Lkb



Lvl



Lvt



Lyx



Mep



Mos



Mqq



Mrs



Mup



Nam



Noc



Nor



Npp



Nss



Nze



Pch



Pds



Peg



Pns



Psa



Ptr



Pve



Rol



Ros



Rtg



Rtp



Rtr



Scl



Scp



Sec



Seu



Sic



Sip



Sit



Slb



Spg



Ssk



St2



Stg



Tbf



Tch



Tgt



Thb



Thn



Tis



Top



Ttd



Ube



Uis



Upi



Vcs



Xct



Zen



Zet



Zis



Isg



Nbo



Isw



I27



B27



Ukd



Scr



Rix



Moc



Unknown